@@ -686,15 +686,18 @@ img_prepare_pixbufs( img_window_struct *img)
 								img->video_size[0],
 								img->video_size[1], NULL, &img->image2 );
 		}
-		success = img_scale_image( img->current_slide->p_filename, img->video_ratio,
-							 0, img->video_size[1], img->distort_images,
-							 img->background_color, NULL, &img->image2 );
+		else
+		{
+			success = img_scale_image( img->current_slide->p_filename, img->video_ratio,
+								0, img->video_size[1], img->distort_images,
+								img->background_color, NULL, &img->image2 );
 
-		if (!success) {
-
-		    img->image2 = NULL;
-		    img_fail_export(img, "while loading file %s", img->current_slide->p_filename);
-		    return (FALSE);
+			if (!success)
+			{
+				img->image2 = NULL;
+				img_fail_export(img, "while loading file %s", img->current_slide->p_filename);
+				return (FALSE);
+			}
 		}
 		/* Get first stop point */
 		img->point2 = (ImgStopPoint *)( img->current_slide->no_points ?
@@ -1410,9 +1413,10 @@ void img_exporter (GtkWidget * UNUSED(button), img_window_struct *img )
 
 
 	cmd_line = g_strdup_printf("%s -f image2pipe -vcodec ppm "
+				"-framerate %d/%d "
 				"-i pipe: <#AUDIO#> "
-				"-r %s "                /* frame rate */
 				"-y "                   /* overwrite output */
+                "%s "                   /* framerate option */
                 "%s "                   /* ffmpeg option */
                 "-s %dx%d "             /* size */
                 "%s "                   /* aspect ratio */
@@ -1420,6 +1424,8 @@ void img_exporter (GtkWidget * UNUSED(button), img_window_struct *img )
                 "%s "
                 "\"%s\"",               /*filename */
                  img->encoder_name,
+                video_format_list[img->video_format_index].fps_list[img->fps_index].numerator,
+                video_format_list[img->video_format_index].fps_list[img->fps_index].denominator,
                 video_format_list[img->video_format_index].fps_list[img->fps_index].ffmpeg_option,
                 video_format_list[img->video_format_index].ffmpeg_option,
                 img->video_size[0], img->video_size[1],
