@@ -1,5 +1,5 @@
 /*
-** Copyright (c) 2009 Giuseppe Torelli <colossus73@gmail.com>
+** Copyright (c) 2009-2019 Giuseppe Torelli <colossus73@gmail.com>
 ** Copyright (C) 2009 Tadej Borovšak   <tadeboro@gmail.com>
 **  
 ** This program is free software; you can redistribute it and/or modify
@@ -27,13 +27,22 @@ gboolean
 img_stop_export( img_window_struct *img );
 
 gboolean
-img_prepare_pixbufs( img_window_struct *img,
+img_prepare_pixbufs( img_window_struct *img);
+gboolean
+on_close_export_dialog(GtkWidget *widget,
+						GdkEvent *event,
+						img_window_struct *img);
 
-					 gboolean           preview );
-guint
+gdouble
 img_calc_next_slide_time_offset( img_window_struct *img,
 								 gdouble            rate );
 
+void
+img_post_export(img_window_struct *img);
+
+void
+img_close_export_dialog(img_window_struct *img);
+
 void
 img_exporter_vob( img_window_struct *img );
 
@@ -45,6 +54,10 @@ img_render_still_frame( img_window_struct *img,
 						gdouble            rate );
 
 void
-img_choose_exporter(GtkWidget *button, img_window_struct *img);
+img_exporter(GtkWidget *button, img_window_struct *img);
+
+void
+test_ffmpeg(img_window_struct *img);
+
 
 #endif
