@@ -27,6 +27,7 @@
 #include "main-window.h"
 #include "support.h"
 #include "callbacks.h"
+#include "export.h"
 
 extern void output_message(unsigned , const char *, const char *, va_list ap);
 
@@ -40,10 +41,6 @@ int main (int argc, char *argv[])
   		textdomain (GETTEXT_PACKAGE);
 	#endif
 	
-	if( ! g_thread_supported() )
-		g_thread_init( NULL );
-
-	gtk_set_locale ();
 	gtk_init (&argc, &argv);
 	
 	sox_globals.output_message_handler = output_message;
@@ -51,6 +48,9 @@ int main (int argc, char *argv[])
 
 	img_window = img_create_window();
 
+	/* Create the GTK rich text tags */
+	img_set_text_buffer_tags(img_window);
+	
 	/* Load the transitions as plugins with GModule */
 	img_load_available_transitions(img_window);
 
@@ -63,6 +63,8 @@ int main (int argc, char *argv[])
 		img_load_slideshow( img_window, argv[1] );
 	}
 
+    test_ffmpeg(img_window);
+
 	gtk_main ();
 
 	sox_format_quit();
