@@ -335,7 +335,8 @@ img_append_slides_from( img_window_struct *img, const gchar *input )
 	}
 	else
 		img->fps_index = i;
-	img->export_fps = video_format_list[img->video_format_index].fps_list[img->fps_index].value;
+	img->export_fps = video_format_list[img->video_format_index].fps_list[img->fps_index].numerator;
+	img->export_fps /= video_format_list[img->video_format_index].fps_list[img->fps_index].denominator;
 
   /* Aspect ratio */
   if (NULL != video_format_list[img->video_format_index].aspect_ratio_list)
@@ -448,7 +449,6 @@ img_append_slides_from( img_window_struct *img, const gchar *input )
                                                            GTK_ICON_LOOKUP_FORCE_SVG);
                     icon_filename = gtk_icon_info_get_filename(icon_info);
 
-
                     img_message(img, TRUE, _("Slide %i: can't load image %s\n"), i, slide_filename);
 
                     g_free (slide_filename);
@@ -511,8 +511,13 @@ img_append_slides_from( img_window_struct *img, const gchar *input )
 
 				/* Get the mem address of the transition */
 				spath = (gchar *)g_hash_table_lookup( table, GINT_TO_POINTER( transition_id ) );
-				gtk_tree_model_get_iter_from_string( model, &iter, spath );
-				gtk_tree_model_get( model, &iter, 2, &render, 0, &pix, -1 );
+				if (spath) {
+				  gtk_tree_model_get_iter_from_string( model, &iter, spath );
+				  gtk_tree_model_get( model, &iter, 2, &render, 0, &pix, -1 );
+				} else {
+				  img_message(img, TRUE, _("Slide %d: Unknown transition id %d\n"), i, transition_id);
+				  transition_id = -1;
+				}
 
 				slide_info = img_create_new_slide();
 				if( slide_info )
@@ -532,7 +537,7 @@ img_append_slides_from( img_window_struct *img, const gchar *input )
 
 					
 					/* If image has been flipped or rotated, do it now too. */
-					if( flipped || angle)
+					if( (flipped || angle) && ! g_strrstr(icon_filename,"image-missing"))
 					{
 						img_rotate_flip_slide( slide_info, angle, flipped, NULL );
 						g_object_unref( thumb );
@@ -540,8 +545,7 @@ img_append_slides_from( img_window_struct *img, const gchar *input )
 										 88, 0, img->distort_images,
 										 img->background_color, &thumb, NULL );
 					}
-
-					gtk_list_store_append( img->thumbnail_model, &iter );
+					gtk_list_store_append( img->thumbnail_model, &iter );                   
 					gtk_list_store_set( img->thumbnail_model, &iter,
 										0, thumb,
 										1, slide_info,
