@@ -1,6 +1,5 @@
 /*
 ** Copyright (C) 2009 Tadej Borovšak <tadeboro@gmail.com>
-** Copyright (C) 2010 Robert Chéramy <robert@cheramy.net>
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -40,19 +39,40 @@ img_free_text_animation_list( gint           no_animations,
 							  TextAnimation *animations );
 
 void
-img_render_subtitle( cairo_t              *cr,
-					 gint                  width,
-					 gint                  height,
+img_render_subtitle( img_window_struct	  *img,
+					 cairo_t              *cr,
 					 gdouble               zoom,
-					 ImgSubPos             position,
-					 ImgRelPlacing         placing,
+					 gint					posx,
+					 gint					posy,
+					 gint					angle,
+					 gint					layout,
 					 gdouble               factor,
 					 gdouble               offx,
 					 gdouble               offy,
-					 gchar                *subtitle,
-					 PangoFontDescription *font_desc,
-					 gdouble              *font_color,
-                     gdouble              *font_bgcolor,
-					 TextAnimationFunc     func,
+					 gboolean				centerX,
+					 gboolean				centerY,
 					 gdouble               progress );
+
+void
+img_set_slide_text_info( slide_struct      *slide,
+						 GtkListStore      *store,
+						 GtkTreeIter       *iter,
+						 guint8		       *subtitle,
+						 gchar		       *pattern_filename,
+						 gint	            anim_id,
+						 gint               anim_duration,
+						 gint               posx,
+						 gint               posy,
+						 gint               angle,
+						 const gchar       *font_desc,
+						 gdouble           *font_color,
+                         gdouble           *font_brdr_color,
+                         gdouble           *font_bgcolor,
+                         gdouble           *border_color,
+                         gboolean			top_border,
+						 gboolean			bottom_border,
+                         gint	           alignment,
+                         gint	           border_width,
+						 img_window_struct *img );
+
 #endif
