@@ -144,28 +144,26 @@ void img_set_statusbar_message(img_window_struct *img_struct, gint selected)
 							img_struct->context_id, message );
 		g_free( message );
 		gtk_label_set_text( GTK_LABEL( img_struct->total_slide_number_label ), NULL );
+		gtk_icon_view_set_columns (GTK_ICON_VIEW (img_struct->thumbnail_iconview), -1);
 	}
-	else if (selected)
-	{
-		message = g_strdup_printf( ngettext( "%d slide selected",
-											 "%d slides selected",
-											 selected ), selected);
-		gtk_statusbar_push( GTK_STATUSBAR( img_struct->statusbar ),
-							img_struct->context_id, message );
-		g_free( message );
-	}
-	else
+	else 
 	{
 		total_slides = g_strdup_printf("%d",img_struct->slides_nr);
 		gtk_label_set_text(GTK_LABEL(img_struct->total_slide_number_label),total_slides);
-		message = g_strdup_printf( ngettext( "%d slide loaded %s",
-											 "%d slides loaded %s",
-											 img_struct->slides_nr ),
-								   img_struct->slides_nr,
-								   _(" - Use the CTRL key to select/unselect "
-									 "or SHIFT for multiple select") );
+	    if (selected)
+			message = g_strdup_printf( ngettext( "%d slide selected",
+						"%d slides selected",
+						selected ), selected);
+		else
+			message = g_strdup_printf( ngettext( "%d slide loaded %s",
+						"%d slides loaded %s",
+						img_struct->slides_nr ),
+					img_struct->slides_nr,
+					_(" - Use the CTRL key to select/unselect "
+						"or SHIFT for multiple select") );
 		gtk_statusbar_push( GTK_STATUSBAR( img_struct->statusbar ),
 							img_struct->context_id, message );
+		gtk_icon_view_set_columns (GTK_ICON_VIEW (img_struct->thumbnail_iconview), img_struct->slides_nr + 1);
 		g_free(total_slides);
 		g_free(message);
 	}
@@ -469,7 +467,7 @@ img_set_slide_file_info( slide_struct *slide,
 	slide->angle = 0;
 
 	slide->resolution = g_strdup_printf( "%d x %d", width, height );
-	slide->type = gdk_pixbuf_format_get_name( format );
+	slide->type = format ? gdk_pixbuf_format_get_name( format ) : NULL;
 }
 
 void
@@ -627,7 +625,7 @@ img_free_slide_struct( slide_struct *entry )
 
 	g_free(entry->o_filename);
 	g_free(entry->resolution);
-	g_free(entry->type);
+	if (entry->type) g_free(entry->type);
 	
 	if (entry->subtitle)
 		g_free(entry->subtitle);
